RezConfigProvider

Struct RezConfigProvider 

pub struct RezConfigProvider { /* private fields */ }
Implementation of ConfigProvider that reads from environment variables.

Implementations

Source

impl RezConfigProvider

pub fn new() -> Self

Create a new configuration provider.

pub async fn load_from_environment(&mut self) -> Result<()>

Load configuration from environment variables.

This method reads Rez configuration from standard environment variables:

  • REZ_PACKAGES_PATH: Colon/semicolon-separated list of package directories
  • REZ_LOCAL_PACKAGES_PATH: Local packages directory (highest priority)
  • REZ_RELEASE_PACKAGES_PATH: Release packages directory (lowest priority)
  • REZ_LSP_DEBUG: Enable debug logging (true/1)
Errors

Returns an error if environment variables contain invalid paths or values.

pub fn config(&self) -> &Config

Get the current configuration.