pub struct Cache<K, V> { /* private fields */ }Expand description
A thread-safe cache with TTL support.
Implementations
Sourceimpl<K, V> Cache<K, V>
impl<K, V> Cache<K, V>
Sourcepub fn new(default_ttl: Duration, max_size: usize) -> Self
pub fn new(default_ttl: Duration, max_size: usize) -> Self
Create a new cache with the given default TTL and maximum size.
Sourcepub async fn put_with_ttl(&self, key: K, value: V, ttl: Duration)
pub async fn put_with_ttl(&self, key: K, value: V, ttl: Duration)
Put a value into the cache with custom TTL.
Sourcepub async fn stats(&self) -> CacheStats
pub async fn stats(&self) -> CacheStats
Get cache statistics.