pub struct ValidationResult {
pub file_path: String,
pub issues: Vec<ValidationIssue>,
pub stats: ValidationStats,
}Expand description
Result of a validation operation.
Fields
file_path: StringThe file that was validated
issues: Vec<ValidationIssue>All issues found during validation
stats: ValidationStatsStatistics about the validation
Implementations
Sourceimpl ValidationResult
impl ValidationResult
Sourcepub fn new(
file_path: impl Into<String>,
issues: Vec<ValidationIssue>,
validation_time_ms: u64,
) -> Self
pub fn new( file_path: impl Into<String>, issues: Vec<ValidationIssue>, validation_time_ms: u64, ) -> Self
Create a new validation result.
Sourcepub fn has_errors(&self) -> bool
pub fn has_errors(&self) -> bool
Check if the validation found any errors or critical issues.
Sourcepub fn has_issues(&self) -> bool
pub fn has_issues(&self) -> bool
Check if the validation found any issues at all.